# @gradio/navbar

## 0.2.7

### Dependency updates

- @gradio/statustracker@0.12.5
- @gradio/utils@0.12.0
- @gradio/atoms@0.22.2
- @gradio/core@1.4.0

## 0.2.6

### Dependency updates

- @gradio/utils@0.11.3
- @gradio/atoms@0.22.0
- @gradio/statustracker@0.12.4
- @gradio/core@1.2.0

## 0.2.5

### Dependency updates

- @gradio/atoms@0.21.0
- @gradio/statustracker@0.12.3
- @gradio/core@1.1.3

## 0.2.4

### Fixes

- [#12800](https://github.com/gradio-app/gradio/pull/12800) [`7a1c321`](https://github.com/gradio-app/gradio/commit/7a1c321b6546ba05a353488f5133e8262c4a8a39) - Bump svelte/kit for security reasons.  Thanks @freddyaboulton!

### Dependency updates

- @gradio/statustracker@0.12.2
- @gradio/atoms@0.20.1
- @gradio/utils@0.11.2
- @gradio/core@1.1.2

## 0.2.3

### Dependency updates

- @gradio/utils@0.11.1
- @gradio/core@1.1.1

## 0.2.3

### Dependency updates

- @gradio/atoms@0.20.0
- @gradio/utils@0.11.0
- @gradio/statustracker@0.12.1
- @gradio/core@1.1.0

## 0.2.2

### Dependency updates

- @gradio/core@1.0.2

## 0.2.2

### Dependency updates

- @gradio/core@1.0.1
- @gradio/utils@0.10.4

## 0.2.2

### Features

- [#11908](https://github.com/gradio-app/gradio/pull/11908) [`029034f`](https://github.com/gradio-app/gradio/commit/029034f7853ea018d110efe9b7e2ef7d1407091c) - Add back default values for labels
- [#11908](https://github.com/gradio-app/gradio/pull/11908) [`029034f`](https://github.com/gradio-app/gradio/commit/029034f7853ea018d110efe9b7e2ef7d1407091c) - Unit test fixes
- [#12438](https://github.com/gradio-app/gradio/pull/12438) [`25ffc03`](https://github.com/gradio-app/gradio/commit/25ffc0398f8feb43d817c02b2ab970c16de6d797) - Svelte5 migration and bugfix

### Dependencies

- @gradio/atoms@0.19.0
- @gradio/core@1.0.0
- @gradio/statustracker@0.12.0
- @gradio/utils@0.10.3

## 0.2.2-dev.2

### Dependency updates

- @gradio/atoms@0.19.0-dev.1
- @gradio/core@1.0.0-dev.3
- @gradio/statustracker@0.12.0-dev.1

## 0.2.2-dev.1

### Dependency updates

- @gradio/atoms@0.18.2-dev.0
- @gradio/utils@0.10.3-dev.0
- @gradio/statustracker@0.12.0-dev.0
- @gradio/core@1.0.0-dev.1

## 0.2.2-dev.0

### Dependency updates

- @gradio/core@1.0.0-dev.0

## 0.2.1

### Dependency updates

- @gradio/core@0.29.2

## 0.2.1

### Dependency updates

- @gradio/atoms@0.18.1

## 0.2.1

### Dependency updates

- @gradio/statustracker@0.11.1
- @gradio/atoms@0.18.0
- @gradio/core@0.29.0

## 0.2.0

### Features

- [#11833](https://github.com/gradio-app/gradio/pull/11833) [`a446fcb`](https://github.com/gradio-app/gradio/commit/a446fcba6f3fe59c32194beb7f27fb6f80b61347) - Add gr.Navbar component for multipage apps.  Thanks @abidlabs!

### Dependency updates

- @gradio/core@0.28.0
- @gradio/atoms@0.17.0
- @gradio/statustracker@0.11.0

## 0.1.0

### Features

- Initial implementation of Navbar component for multipage apps ([#xxxx](https://github.com/gradio-app/gradio/pull/xxxx))